package com.kaspersky.kaspressample.device_tests

import android.Manifest
import android.content.res.Configuration
import androidx.test.ext.junit.runners.AndroidJUnit4
import androidx.test.rule.ActivityTestRule
import androidx.test.rule.GrantPermissionRule
import com.agoda.kakao.screen.Screen
import com.kaspersky.kaspressample.MainActivity
import com.kaspersky.kaspressample.screen.MainScreen
import com.kaspersky.kaspresso.device.exploit.Exploit
import com.kaspersky.kaspresso.testcases.api.testcase.TestCase
import org.junit.Assert.assertEquals
import org.junit.Assert.assertNull
import org.junit.Rule
import org.junit.Test
import org.junit.runner.RunWith

@RunWith(AndroidJUnit4::class)
class DeviceExploitSampleTest : TestCase() {

    companion object {
        const val ROTATION_ANIMATION_DELAY = 1000L
    }

    @get:Rule
    val runtimePermissionRule: GrantPermissionRule = GrantPermissionRule.grant(
        Manifest.permission.WRITE_EXTERNAL_STORAGE,
        Manifest.permission.READ_EXTERNAL_STORAGE
    )

    @get:Rule
    val activityTestRule = ActivityTestRule(MainActivity::class.java, true, true)

    @Test
    fun exploitSampleTest() {
        before {
            device.exploit.setOrientation(Exploit.DeviceOrientation.Portrait)
            device.exploit.setAutoRotationEnabled(true)
        }.after {
            device.exploit.setOrientation(Exploit.DeviceOrientation.Portrait)
            device.exploit.setAutoRotationEnabled(true)
        }.run {

            step("Change orientation manually") {
                device.exploit.setOrientation(Exploit.DeviceOrientation.Landscape)
                Screen.idle(ROTATION_ANIMATION_DELAY) // wait for animation end
                assertEquals(
                    Configuration.ORIENTATION_LANDSCAPE,
                    activityTestRule.activity.resources.configuration.orientation
                )

                device.exploit.setOrientation(Exploit.DeviceOrientation.Portrait)
                Screen.idle(ROTATION_ANIMATION_DELAY) // wait for animation end
                assertEquals(
                    Configuration.ORIENTATION_PORTRAIT,
                    activityTestRule.activity.resources.configuration.orientation
                )
            }

            step("Rotate device") {
                device.exploit.rotate()
                Screen.idle(ROTATION_ANIMATION_DELAY) // wait for animation end
                assertEquals(
                    Configuration.ORIENTATION_LANDSCAPE,
                    activityTestRule.activity.resources.configuration.orientation
                )
            }

            step("Disable auto rotation") {
                device.exploit.setOrientation(Exploit.DeviceOrientation.Portrait)
                device.exploit.setAutoRotationEnabled(false)
                Screen.idle(ROTATION_ANIMATION_DELAY) // wait for animation end
                device.exploit.rotate() // Won't rotate
                assertEquals(
                    Configuration.ORIENTATION_PORTRAIT,
                    activityTestRule.activity.resources.configuration.orientation
                )
            }

            step("Press back button") {
                MainScreen {
                    webViewButton {
                        click()
                    }
                }

                device.exploit.pressBack(true)
                device.activities.isCurrent(MainActivity::class.java) // Asserts that MainActivity is resumed
            }

            step("Press home button") {
                device.exploit.pressHome()
                assertNull(device.activities.getResumed())
            }
        }
    }
}